package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TaCheckAnswer;
import com.example.civilizedcity.service.TaCheckAnswerService;

 /**
 * 测评作答;(ta_check_answer)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-13
 */
@Api(tags = "测评作答对象功能接口")
@RestController
@RequestMapping("/")
public class TaCheckAnswerController extends BaseController {
    
    @Autowired
    private TaCheckAnswerService taCheckAnswerService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param answerId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taCheckAnswer/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taCheckAnswerService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taCheckAnswer")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaCheckAnswer> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaCheckAnswer> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaCheckAnswer> result = taCheckAnswerService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taCheckAnswer 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taCheckAnswer")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaCheckAnswer taCheckAnswer) throws Exception {
        taCheckAnswerService.save(taCheckAnswer);
        return ResponseBean.success(taCheckAnswer);
    }
    
    /** 
     * 更新数据
     *
     * @param taCheckAnswer 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taCheckAnswer/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaCheckAnswer taCheckAnswer,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taCheckAnswerService.updateById(taCheckAnswer);
        return ResponseBean.success(taCheckAnswer);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param answerId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taCheckAnswer/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taCheckAnswerService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}