package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.Constants;
import com.example.civilizedcity.common.ResponseBean;

import java.time.LocalDateTime;
import java.util.List;

import com.example.civilizedcity.common.StringUtils;
import com.example.civilizedcity.entity.SysUser;
import com.example.civilizedcity.event.MessagEvent;
import com.example.civilizedcity.service.SysUserDutyService;
import com.example.civilizedcity.service.TaIssueService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TaIssueApply;
import com.example.civilizedcity.service.TaIssueApplyService;

/**
 * 问题处理申请;(ta_issue_apply)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-12-27
 */
@Api(tags = "问题处理申请对象功能接口")
@RestController
@RequestMapping("/")
public class TaIssueApplyController extends BaseController {

    @Autowired
    private TaIssueApplyService taIssueApplyService;

    @Autowired
    private TaIssueService taIssueService;

    @Autowired
    private SysUserDutyService sysUserDutyService;

    @Autowired
    ApplicationEventPublisher applicationEventPublisher;

    /**
     * 通过ID查询单条数据
     *
     * @param applyId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taIssueApply/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(taIssueApplyService.getById(id));
    }
    /**
     * 通过ISSUE_ID查询单条数据
     *
     * @param applyId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ISSUE_ID查询单条数据")
    @GetMapping("/taIssue/{issueId}/apply")
    public ResponseBean queryByIssueId(@ApiParam("问题单ID") @PathVariable Integer issueId,
                                       @ApiParam("申请类型") @RequestParam("applyType") String applyType) throws Exception {

        SysUser sysUser = currentUser();
        boolean isManager = isManager(sysUser);

        QueryWrapper<TaIssueApply> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("issue_id", issueId);
        queryWrapper.eq("apply_type", applyType);
        if (!isManager) {
            queryWrapper.eq("org_id", sysUser.getOrgId());
        }
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.orderByDesc("create_date");
        queryWrapper.last("limit 1");

        TaIssueApply taIssueApply = taIssueApplyService.getOne(queryWrapper);

        return ResponseBean.success(taIssueApply);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taIssueApply")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("问题单ID") @RequestParam(value = "issueId", required = false) Integer issueId,
                             @ApiParam("申请类型") @RequestParam(value = "applyType", required = false) String applyType,
                             @ApiParam("问题单来源") @RequestParam(value = "sourceType", required = false) String sourceType) throws Exception {

        SysUser sysUser = currentUser();
        String orgId = isManager(sysUser) ? null : sysUser.getOrgId();

        IPage<TaIssueApply> pg = new Page<>(pageNum, pageSize);
        IPage<TaIssueApply> result = taIssueApplyService.getPageBy(pg, issueId, applyType, orgId, sourceType);

        return ResponseBean.success(result);
    }

    /**
     * 申请流程
     *
     * @param taIssueApply 实例对象
     * @return 实例对象
     */
    @ApiOperation("申请流程")
    @PostMapping("/taIssueApply")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaIssueApply taIssueApply) throws Exception {
        taIssueApplyService.createNewApply(taIssueApply, currentUser());
        return ResponseBean.success(taIssueApply);
    }

    /**
     * 审批流程
     *
     * @param taIssueApply 实例对象
     * @return 实例对象
     */
    @ApiOperation("审批流程")
    @PutMapping("/taIssueApply/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaIssueApply taIssueApply,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {

        TaIssueApply origin = taIssueApplyService.getById(id);
        if (null == origin || Constants.STATUS_DELETE == origin.getStatus()) {
            return ResponseBean.error("未找到申请数据");
        }

        SysUser sysUser = currentUser();

//        // 如果是问题单审核
//        if (Constants.APPLY_VERIFY.equals(origin.getApplyType())) {
//            if (StringUtils.isEmpty(taIssueApply.getVerifyDesc()) && Constants.APPLY_STATUS_REJECT.equals(taIssueApply.getVerifyStatus())) {
//                return ResponseBean.error("请填写驳回理由");
//            }
//        }

        origin.setVerifyStatus(taIssueApply.getVerifyStatus());
        origin.setVerifyDesc(taIssueApply.getVerifyDesc());
        origin.setVerifyOrg(sysUser.getOrgId());
        origin.setVerifyUser(sysUser.getUserId());
        origin.setVerifyUserName(sysUser.getName());
        origin.setVerifyDate(LocalDateTime.now());

        taIssueApplyService.updateById(origin);

        //
        taIssueService.updateApply(taIssueApply.getIssueId(), null, null);

        // 如果是销单申请
        if (Constants.APPLY_END.equals(origin.getApplyType())) {
            if (Constants.APPLY_STATUS_PASS.equals(taIssueApply.getVerifyStatus())) {
                // 如果通过
                taIssueService.updateEnd(sysUser, taIssueApply.getOrgId(), taIssueApply.getIssueId());
            }
        }

//        if (Constants.APPLY_VERIFY.equals(origin.getApplyType())) {
//            int validateStatus = Constants.APPLY_STATUS_REJECT.equals(taIssueApply.getVerifyStatus()) ? Constants.VERIFY_REJECT : Constants.VERIFY_PASS;
//            taIssueService.updateValidateStatus(taIssueApply.getIssueId(), validateStatus);
//        }


        applicationEventPublisher.publishEvent(new MessagEvent(this, origin));

        return ResponseBean.success(origin);
    }

    /**
     * 通过主键删除数据
     *
     * @param applyId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taIssueApply/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        taIssueApplyService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}