package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.Constants;
import com.example.civilizedcity.common.ResponseBean;
import java.util.List;

import com.example.civilizedcity.entity.SysUser;
import com.example.civilizedcity.entity.TaAttach;
import com.example.civilizedcity.entity.TaIssue;
import com.example.civilizedcity.service.TaAttachService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TaOrgIssue;
import com.example.civilizedcity.service.TaOrgIssueService;

import javax.xml.ws.Response;

/**
 * 单位问题单;(ta_org_issue)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-28
 */
@Api(tags = "单位问题单对象功能接口")
@RestController
@RequestMapping("/")
public class TaOrgIssueController extends BaseController {
    
    @Autowired
    private TaOrgIssueService taOrgIssueService;

    @Autowired
    private TaAttachService taAttachService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param orgIssueId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taOrgIssue/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(taOrgIssueService.getById(id));
    }
     /**
      * 通过ISSUE_ID查询单条数据
      *
      * @param issueId 主键
      * @return 实例对象
      */
     @ApiOperation("通过ISSUE_ID查询单条数据")
     @GetMapping("/taIssue/{issueId}/orgIssue")
     public ResponseBean queryByIssueId(@ApiParam("对象ID") @PathVariable Integer issueId) throws Exception {

         QueryWrapper<TaOrgIssue> queryWrapper = new QueryWrapper<>();
         queryWrapper.eq("issue_id", issueId);
         queryWrapper.eq("status", Constants.STATUS_NORMAL);

         TaOrgIssue taOrgIssue = taOrgIssueService.getOne(queryWrapper);
         if (null != taOrgIssue) {
             List<TaAttach> attachList = taAttachService.getListBy(Constants.ATTACH_SOURCE_ORG_ISSUE, taOrgIssue.getOrgIssueId().toString());
             taOrgIssue.setAttachList(attachList);
         }

         return ResponseBean.success(taOrgIssue);
     }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taOrgIssue")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("数据来源") @RequestParam(value ="sourceType", required = false) String sourceType,
                             @ApiParam("业务状态") @RequestParam(value ="bizStatus", required = false) String bizStatus) throws Exception {
        SysUser sysUser = currentUser();

        IPage<TaIssue> pg = new Page<>(pageNum, pageSize);
        IPage<TaIssue> result = taOrgIssueService.getIssuePageBy(pg, sysUser.getOrgId(), sourceType, bizStatus);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taOrgIssue 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taOrgIssue")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaOrgIssue taOrgIssue) throws Exception {
        taOrgIssueService.save(taOrgIssue);
        return ResponseBean.success(taOrgIssue);
    }
    
    /** 
     * 更新数据
     *
     * @param taOrgIssue 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taOrgIssue/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaOrgIssue taOrgIssue,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        taOrgIssueService.updateById(taOrgIssue);
        return ResponseBean.success(taOrgIssue);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param orgIssueId 主键
     * @return 是否成功
     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/taOrgIssue/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
//        taOrgIssueService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }


/**
 * 通过主键删除数据
 *
 * @param orgIssueId
 * @return 是否成功
 *
 */

      @ApiOperation(value="通过主键删除数据",httpMethod="DELETE")
      @DeleteMapping("/taOrgIssue/{issueId}")
     public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String issueId){
          taOrgIssueService.removeByIssueId(issueId);
          return ResponseBean.success("success成功删除");
      }

}

